@@ -1,5 +1,3 @@
-import os
-
 from datasets import load_dataset
 import pandas as pd
 import pytest
@@ -10,11 +8,6 @@ import tune_the_model as ttm
 TRAIN_ITERS = 101
 
 
-@pytest.fixture(scope='session')
-def configured_tune_the_model():
-    ttm.set_api_key(os.environ.get("TTM_API_KEY"))
-
-
 @pytest.fixture(scope="session")
 def dataset():
     yield load_dataset("tweet_eval", "irony")
